# NuriKit

[![Test main branch](https://img.shields.io/github/actions/workflow/status/seoklab/nurikit/main-test.yaml?branch=main&event=push&logo=github&label=Test%20main%20branch)](https://github.com/seoklab/nurikit/actions/workflows/main-test.yaml) [![Build test wheels](https://img.shields.io/github/actions/workflow/status/seoklab/nurikit/wheels-matrix.yaml?branch=main&event=push&logo=github&label=Build%20test%20wheels)](https://github.com/seoklab/nurikit/actions/workflows/wheels-matrix.yaml) [![Read the Docs](https://img.shields.io/readthedocs/nurikit/latest?logo=readthedocs)](https://nurikit.readthedocs.io/latest) [![Codecov](https://img.shields.io/codecov/c/github/seoklab/nurikit?logo=codecov)](https://codecov.io/gh/seoklab/nurikit)  
[![PyPI - Version](https://img.shields.io/pypi/v/nurikit?logo=pypi&color=blue)](https://pypi.org/p/nurikit) [![Conda Version](https://img.shields.io/conda/vn/conda-forge/nurikit?logo=anaconda&color=blue)](https://anaconda.org/conda-forge/nurikit)

## Introduction

NuriKit is *the* fundamental software platform for chem- and bio-informatics,
aims to succeed [RDKit](https://github.com/rdkit/rdkit) and
[OpenBabel](https://github.com/openbabel/openbabel) with a modern, clean,
and extensible design.

## Documentation

See <https://nurikit.readthedocs.io>.

## Contributing

We welcome contributions from everyone. Please read our
[contributing guidelines](CONTRIBUTING.md) before you start.

## License and Disclaimer

NuriKit is licensed under the **Apache 2.0 License**. See the [LICENSE](LICENSE)
file for details.
